export interface DijkstraEdge<T extends number | bigint> {
    /**
     * The other end of the edge.
     */
    to: number;
    /**
     * The cost of walking along this side.
     */
    cost: T;
}
/**
 * The dijkstra algorithm, optimized with priority queue.
 *
 * @param N         the number of nodes in the graph
 * @param source    the source node
 * @param G         edges of the graph. G[i] represent the edge list start from node i.
 * @param ZERO      0 for number, 0n for bigint.
 * @param INF       a big number, such as Number.MAX_SAFE_INTEGER
 * @returns
 *
 * @see https://me.guanghechen.com/post/algorithm/graph/shortest-path/dijkstra
 */
export declare function dijkstra<T extends number | bigint>(N: number, source: number, G: ReadonlyArray<ReadonlyArray<DijkstraEdge<T>>>, ZERO: T, INF: T): T[];
export default dijkstra;
